# 开始吧！

欢迎使用Rapunzel，一款现代化的Python和R开发环境。以下是一些方便的键盘快捷键。


## 处理项目文件夹和文件

- [`Ctrl+Shift+O`：打开项目文件夹](opensesame://event.rapunzel_welcome_open_folders)
- [`Ctrl+O`：从项目文件夹中打开文件](opensesame://event.rapunzel_welcome_open_files)
- [`Ctrl+N`：创建空文档](opensesame://event.ide_new_file)


## 快速做事

- [`Ctrl+Shift+P`：激活命令面板](opensesame://event.command_palette_activate)
- `Ctrl+R`：跳转到函数或类


## 运行代码

- `F5`：运行项目或文件
- `F9`：运行所选区域、单元格或当前行
